@@ -297,3 +297,10 @@ def run_rez_pkg_ignore():
     check_production_install()
     from rez.cli._main import run
     return run("pkg-ignore")
+
+
+@scriptname("rez-mv")
+def run_rez_pkg_mv():
+    check_production_install()
+    from rez.cli._main import run
+    return run("mv")
